=====================================
seaflux
=====================================

Brief info

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   installation

.. toctree::
   :maxdepth: 2
   :caption: Users Guide

   documentation

.. toctree::
   :maxdepth: 2
   :caption: Help and Reference

   GitLab Repo <https://github.com/luke-gregor/SeaFlux>
   contributing
